BetterCollapse class

Inheritance

Constructors

BetterCollapse({Key? key, required BetterCollapseItem children, ExpansibleController? expansibleController, bool accordion = false, EdgeInsetsGeometry? titlePadding, VisualDensity? titleVisualDensity, bool? titleDense, double? minTitleHeight = 0, double? titleMinVerticalPadding = 0, EdgeInsetsGeometry? childrenPadding = EdgeInsets.zero, EdgeInsetsGeometry? contentPadding, bool showDivider = true, Color? dividerColor, double? dividerHeight, double dividerThickness = 0, double dividerIndent = 0, double dividerEndIndent = 0, bool showContentTopBorder = true, Color? contentTopBorderColor, double? contentTopBorderWidth, Alignment alignment = Alignment.centerLeft, CrossAxisAlignment expandedCrossAxisAlignment = CrossAxisAlignment.start, Color? background, Color? collapsedBackground, Color? iconColor, Color? collapsedIconColor, Color? splashColor})
const

Properties

accordion bool
final
alignment Alignment
final
background Color?
final
children BetterCollapseItem
final
childrenPadding EdgeInsetsGeometry?
final
collapsedBackground Color?
final
collapsedIconColor Color?
final
contentPadding EdgeInsetsGeometry?
final
contentTopBorderColor Color?
final
contentTopBorderWidth double?
final
dividerColor Color?
final
dividerEndIndent double
final
dividerHeight double?
final
dividerIndent double
final
dividerThickness double
final
expandedCrossAxisAlignment CrossAxisAlignment
final
expansibleController ExpansibleController?
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minTitleHeight double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showContentTopBorder bool
final
showDivider bool
final
splashColor Color?
final
titleDense bool?
final
titleMinVerticalPadding double?
final
titlePadding EdgeInsetsGeometry?
final
titleVisualDensity VisualDensity?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BetterCollapse>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited