BetterDialog class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
showDialog({BuildContext? context, bool barrierDismissible = true, Color? barrierColor, String? title, String? content, bool showConfirmButton = true, bool showCancelButton = false, String confirmButtonText = "确认", Color? confirmButtonColor, bool confirmButtonDisabled = false, String cancelButtonText = "取消", Color? cancelButtonColor, bool cancelButtonDisabled = false, VoidCallback? onConfirm, VoidCallback? onCancel, bool isCloseWhenTap = true, Widget? buttomWidget})
→ dynamic
-