BetterImagePreview class

A full-screen image viewer inspired by Vant's ImagePreview.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({BuildContext? context, required List<String> images, int startPosition = 0, bool loop = true, bool vertical = false, bool doubleScale = true, bool showIndex = true, bool closeable = false, bool closeOnTap = true, BetterImagePreviewClosePosition closePosition = BetterImagePreviewClosePosition.topRight, Color backgroundColor = Colors.black, double minScale = 1, double maxScale = 4, Duration transitionDuration = const Duration(milliseconds: 250), ValueChanged<int>? onChange, ValueChanged<int>? onClose, BetterImagePreviewImageBuilder? imageBuilder, BetterImagePreviewBuilder? loadingBuilder, BetterImagePreviewBuilder? errorBuilder, Widget indexBuilder(BuildContext context, int index, int total)?}) Future<void>
Opens a full-screen image preview.