BetterIndexBarItem class

Constructors

BetterIndexBarItem({required BetterIndexBarHeader header, required List<Widget> list})

Properties

anchor String
no setter
hashCode int
The hash code for this object.
no setterinherited
final
list List<Widget>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited