BetterMarquee class

Inheritance

Constructors

BetterMarquee({Key? key, required List<String> textList, TextStyle? style, double speed = 60, double? width, required double height, Color? backgroundColor, Color? textColor, Widget? leftWidget, Widget? rightWidget, EdgeInsetsGeometry? padding, String? separtor = " ", bool isVertical = false, Duration? autoplayDuration = const Duration(seconds: 3)})
const

Properties

autoplayDuration Duration?
自动播放间隔
final
backgroundColor Color?
背景颜色
final
hashCode int
The hash code for this object.
no setterinherited
height double
高度
final
isVertical bool
是否垂直滚动
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftWidget Widget?
final
padding EdgeInsetsGeometry?
内边距
final
rightWidget Widget?
右侧组件
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separtor String?
分隔符
final
speed double
速度
final
style TextStyle?
文本样式
final
textColor Color?
文本颜色
final
textList List<String>
文本列表
final
width double?
宽度
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BetterMarquee>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited