BetterPickerWidget class

支持单列、多列和级联数据结构的核心选择器组件。

Inheritance

Constructors

BetterPickerWidget({Key? key, required dynamic columns, String? cancelText, String? confirmText, String? title, Widget? titleWidget, Color? headerBackgroundColor, Color? backgroundColor, BorderRadiusGeometry? borderRadius, Color? cancelTextColor, Color? confirmTextColor, VoidCallback? onCancel, dynamic onConfirm(List<BetterPickerItem>)?, dynamic onChange(List<BetterPickerItem>, dynamic (dynamic columns))?, double? diameterRatio, Widget? overlayWidget, double? itemHeight})
创建一个 BetterPickerWidget
const

Properties

backgroundColor Color?
final
borderRadius BorderRadiusGeometry?
final
cancelText String?
final
cancelTextColor Color?
final
columns → dynamic
final
confirmText String?
final
confirmTextColor Color?
final
diameterRatio double?
final
hashCode int
The hash code for this object.
no setterinherited
headerBackgroundColor Color?
final
itemHeight double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCancel VoidCallback?
final
onChange → dynamic Function(List<BetterPickerItem>, dynamic (dynamic columns))?
final
onConfirm → dynamic Function(List<BetterPickerItem>)?
final
overlayWidget Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
titleWidget Widget?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BetterPickerWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited