BetterPopover class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BetterPopover
Constructors
-
BetterPopover({Key? key, required Widget child, List<
BetterPopoverAction> actions = const [], Widget? content, BetterPopoverPlacement placement = BetterPopoverPlacement.bottom, bool? visible, ValueChanged<bool> ? onVisibleChanged, ValueChanged<BetterPopoverAction> ? onSelect, bool closeOnClickAction = true, bool closeOnClickOutside = true, bool showArrow = true, bool enableAnimation = true, Duration animationDuration = const Duration(milliseconds: 100), bool overlay = false, double? width, double? offset, EdgeInsetsGeometry padding = EdgeInsets.zero, Color? backgroundColor}) -
const
Properties
-
actions
→ List<
BetterPopoverAction> -
final
- animationDuration → Duration
-
final
- backgroundColor → Color?
-
final
- child → Widget
-
final
- closeOnClickAction → bool
-
final
- closeOnClickOutside → bool
-
final
- content → Widget?
-
final
- enableAnimation → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- offset → double?
-
final
-
onSelect
→ ValueChanged<
BetterPopoverAction> ? -
final
-
onVisibleChanged
→ ValueChanged<
bool> ? -
final
- overlay → bool
-
final
- padding → EdgeInsetsGeometry
-
final
- placement → BetterPopoverPlacement
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArrow → bool
-
final
- visible → bool?
-
final
- width → double?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BetterPopover> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited