BetterSliderController class

Controls the value displayed by a BetterSlider.

Inheritance

Constructors

BetterSliderController({double initialValue = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
decrease([double amount = 1]) → void
Decreases the current value by amount.
dispose() → void
Discards any resources used by the object.
inherited
increase([double amount = 1]) → void
Increases the current value by amount.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setValue(double value) → void
Changes the slider to value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited