BetterSwipeCellAction class

Constructors

BetterSwipeCellAction({required Widget child, double? width, String? value, Future<bool> onClick(String? value)?})

Properties

child Widget
操作按钮的子组件
final
hashCode int
The hash code for this object.
no setterinherited
onClick Future<bool> Function(String? value)?
操作按钮的点击回调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
操作按钮的值
final
width double?
操作按钮的宽度
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited