BetterSwiper class

Inheritance

Constructors

BetterSwiper({Key? key, required PageController controller, required List<Widget> children, double? width, required double height, bool? autoplay = true, Duration autoplayDuration = const Duration(seconds: 3), Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut, int initialIndex = 0, Color? indicatorColor = Colors.white, double? dotSize, bool? showIndicator = true, Axis scrollDirection = Axis.horizontal, bool touchable = true, bool lazyRender = false, bool loop = true, BetterSwiperIndicatorType indicatorType = BetterSwiperIndicatorType.dot, ValueChanged<int>? onChanged, Widget? indicatorWidget})
const

Properties

autoplay bool?
final
autoplayDuration Duration
final
children List<Widget>
final
controller PageController
final
curve Curve
final
dotSize double?
final
duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
indicatorColor Color?
final
indicatorType BetterSwiperIndicatorType
final
indicatorWidget Widget?
final
initialIndex int
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lazyRender bool
final
loop bool
final
onChanged ValueChanged<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection Axis
final
showIndicator bool?
final
touchable bool
final
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BetterSwiper>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited