better_ui library

Classes

BetterImagePreview
BetterLocalizations
Lightweight runtime translations used by BetterUi.
BetterPopover
BetterPopoverAction
BetterProgress
BetterProgressController
Controls the value displayed by a BetterProgress.
BetterSkeletonConfig
骨架屏上下文配置。
BetterSkeletonizer
像 skeletonizer 一样包裹页面或列表区域,开启后自动以灰色骨架替代原绘制。
BetterSlider
A slider for selecting a single value or a range.
BetterSliderController
Controls the value displayed by a BetterSlider.
BetterUi
Global Better UI configuration for responsive sizing, themes and locale.
BetterUiConfig
Values managed by BetterUi that should be passed to MaterialApp.

Extensions

BetterTranslationExtension on String
Translates a string using the translations configured on BetterUi.

Typedefs

BetterImagePreviewBuilder = Widget Function(BuildContext context, String image, int index)
BetterImagePreviewImageBuilder = Widget Function(BuildContext context, String image, int index, Widget child)
Wraps the default image while preserving its loading and error states.
BetterUiBuilder = Widget Function(BuildContext context, BetterUiConfig config)