BetterUiConfig class

Values managed by BetterUi that should be passed to MaterialApp.

Annotations

Constructors

BetterUiConfig({required ThemeData theme, required ThemeData darkTheme, required ThemeMode themeMode, required Locale locale, required List<Locale> supportedLocales})
const

Properties

darkTheme ThemeData
final
hashCode int
The hash code for this object.
no setterinherited
locale Locale
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedLocales List<Locale>
final
theme ThemeData
final
themeMode ThemeMode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited