BetterLocalizations class

Lightweight runtime translations used by BetterUi.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fallbackLocale Locale
no setter
locale Locale
no setter
localeNotifier ValueNotifier<Locale>
final
supportedLocales List<Locale>
no setter

Static Methods

configure({required Map<String, Map<String, String>> translations, required Locale locale, required Locale fallbackLocale}) → void
translate(String key) String
updateLocale(Locale locale) → void