BetterTranslationExtension extension

Translates a string using the translations configured on BetterUi.

on

Properties

tr String

Available on String, provided by the BetterTranslationExtension extension

no setter

Methods

trParams(Map<String, Object> params) String

Available on String, provided by the BetterTranslationExtension extension

Translates the string and replaces named parameters such as @days.