BetterButtonTheme class

Constructors

BetterButtonTheme({required double fontSize, required EdgeInsetsGeometry padding, BorderRadiusGeometry? borderRadius, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, required Color defaultTextColor, required Color defaultBackgroundColor, required Color borderColor, required Color primaryTextColor, required Color infoTextColor, required Color successTextColor, required Color warningTextColor, required Color dangerTextColor, required Color loadingColor, required Color overlayColor, double? loadingStrokeWidth})
const

Properties

borderColor Color
final
borderRadius BorderRadiusGeometry?
final
dangerTextColor Color
final
defaultBackgroundColor Color
final
defaultTextColor Color
final
fontSize double
final
hashCode int
The hash code for this object.
no setterinherited
infoTextColor Color
final
loadingColor Color
final
loadingStrokeWidth double?
final
mainAxisAlignment MainAxisAlignment
final
overlayColor Color
final
padding EdgeInsetsGeometry
final
primaryTextColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successTextColor Color
final
warningTextColor Color
final

Methods

copyWith({double? fontSize, EdgeInsetsGeometry? padding, BorderRadiusGeometry? borderRadius, MainAxisAlignment? mainAxisAlignment, Color? defaultTextColor, Color? defaultBackgroundColor, Color? borderColor, Color? primaryTextColor, Color? infoTextColor, Color? successTextColor, Color? warningTextColor, Color? dangerTextColor, Color? loadingColor, Color? overlayColor, double? loadingStrokeWidth}) BetterButtonTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(BetterButtonTheme buttonTheme, BetterButtonTheme otherButtonTheme, double t) BetterButtonTheme