BetterCellTheme class
Constructors
- BetterCellTheme({BorderRadiusGeometry? borderRadius, Color? backgroundColor, EdgeInsetsGeometry? padding, TextStyle? titleTextStyle, TextStyle? valueTextStyle, required BoxBorder border, double? arrowRightSize, Color? arrowRightColor, double? arrowRightMarginLeft, Color? overlayColor})
Properties
- arrowRightColor → Color?
-
final
- arrowRightMarginLeft → double?
-
final
- arrowRightSize → double?
-
final
- backgroundColor → Color?
-
final
- border → BoxBorder
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- overlayColor → Color?
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleTextStyle → TextStyle?
-
final
- valueTextStyle → TextStyle?
-
final
Methods
-
copyWith(
{BorderRadiusGeometry? borderRadius, Color? backgroundColor, EdgeInsetsGeometry? padding, TextStyle? titleTextStyle, TextStyle? valueTextStyle, BoxBorder? border, double? arrowRightSize, Color? arrowRightColor, double? arrowRightMarginLeft, Color? overlayColor}) → BetterCellTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
BetterCellTheme cellTheme, BetterCellTheme otherCellTheme, double t) → BetterCellTheme