BetterCollapseTheme class

Constructors

BetterCollapseTheme({Color? backgroundColor, Color? collapsedBackground, Color? iconColor, Color? collapsedIconColor, Color? splashColor})
const

Properties

backgroundColor Color?
final
collapsedBackground Color?
final
collapsedIconColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor Color?
final

Methods

copyWith({Color? backgroundColor, Color? collapsedBackground, Color? iconColor, Color? collapsedIconColor, Color? splashColor}) BetterCollapseTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(BetterCollapseTheme collapseTheme, BetterCollapseTheme otherCollapseTheme, double t) BetterCollapseTheme