BetterAssets class

Constructors

BetterAssets()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate({String projectPath = '', String imagePath = 'assets/images', String codePath = 'lib/app_res', String codeName = 'app_image', String className = 'AppImages', bool sortByLength = false, bool verbose = true, void logger(String message)?}) Future<void>