BetterCell class
一个可配置的列表单元格,常用于设置或表单中
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BetterCell
Constructors
- BetterCell({Key? key, double? height, BorderRadiusGeometry? borderRadius, Color? backgroundColor, EdgeInsetsGeometry? padding, String? titleText, String? valueText, TextStyle? titleTextStyle, TextStyle? valueTextStyle, BoxBorder? border, bool? isShowBorder = false, bool? isShowArrowRight = false, double? arrowRightMarginLeft, double? arrowRightSize, Color? arrowRightColor, Widget? titleWidget, Widget? valueWidget, VoidCallback? onClick, bool? disabled = false, bool? disableSplash = false, Color? overlayColor})
-
创建一个 BetterCell。
const
Properties
- arrowRightColor → Color?
-
右箭头的颜色
final
- arrowRightMarginLeft → double?
-
右箭头的左边距
final
- arrowRightSize → double?
-
右箭头的大小
final
- backgroundColor → Color?
-
单元格的背景颜色
final
- border → BoxBorder?
-
单元格的边框
final
- borderRadius → BorderRadiusGeometry?
-
单元格的圆角半径
final
- disabled → bool?
-
是否禁用单元格
final
- disableSplash → bool?
-
是否禁用水波纹效果
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
单元格的固定高度
final
- isShowArrowRight → bool?
-
是否显示右箭头
final
- isShowBorder → bool?
-
是否显示边框
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClick → VoidCallback?
-
点击回调函数
final
- overlayColor → Color?
-
单元格的覆盖颜色
final
- padding → EdgeInsetsGeometry?
-
单元格的内边距
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleText → String?
-
单元格的标题文本
final
- titleTextStyle → TextStyle?
-
单元格的标题文本样式
final
- titleWidget → Widget?
-
final
- valueText → String?
-
单元格的值文本
final
- valueTextStyle → TextStyle?
-
单元格的值文本样式
final
- valueWidget → Widget?
-
单元格的值组件
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited