BetterPicker class
显示一个模态选择器,支持单列、多列和级联数据结构。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
BuildContext context, {required dynamic columns, String? cancelText, String? confirmText, String? title, Widget? titleWidget, Color? headerBackgroundColor, Color? backgroundColor, BorderRadiusGeometry? borderRadius, Color? cancelTextColor, Color? confirmTextColor, VoidCallback? onCancel, dynamic onConfirm(List< BetterPickerItem> )?, dynamic onChange(List<BetterPickerItem> , dynamic (dynamic columns))?, VoidCallback? onClose, double? diameterRatio, double? itemHeight, Widget? overlayWidget}) → void