BetterPickerItem class
一个由 BetterPickerWidget 显示的项。对于级联选择器,提供嵌套的 children。使用 isSelected 标记默认选择。
Constructors
-
BetterPickerItem({required String text, required String value, TextStyle? textStyle, List<
BetterPickerItem> ? children, bool? isSelected}) - 创建一个 BetterPickerItem。
Properties
-
children
→ List<
BetterPickerItem> ? -
级联选择器的嵌套子项
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSelected → bool?
-
是否选中
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
选择器中显示的文本
final
- textStyle → TextStyle?
-
项的文本样式
final
- value → String
-
与项关联的值
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited