BetterPopup class
显示一个弹出层,支持从不同边缘或中心显示,可选关闭按钮和自定义内容。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
BuildContext context, {BetterPopupPosition position = BetterPopupPosition.bottom, Color? backgroundColor, double? width, double? height, Widget? child, BorderRadiusGeometry? borderRadius, bool isShowCloseIcon = false, double? closeIconSize, Color? closeIconColor, bool isDismissible = true, Widget? closeIcon, EdgeInsets? padding, List< BoxShadow> ? boxShadow, VoidCallback? onClose, bool? enableDrag}) → void