BetterSkeletonConfig class
骨架屏上下文配置。
子组件可以通过 BetterSkeletonConfig.maybeOf 读取当前骨架状态和视觉配置。
- Annotations
Constructors
- BetterSkeletonConfig({required bool enabled, required Color baseColor, required BorderRadius textBorderRadius, required BorderRadius defaultBorderRadius, required int repaintTick})
-
const
Properties
- baseColor → Color
-
final
- defaultBorderRadius → BorderRadius
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- repaintTick → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textBorderRadius → BorderRadius
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf(
BuildContext context) → BetterSkeletonConfig? -
of(
BuildContext context) → BetterSkeletonConfig