BetterSlider class
A slider for selecting a single value or a range.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BetterSlider
Constructors
-
BetterSlider({Key? key, double? value = 0, BetterSliderController? controller, required ValueChanged<
double> ? onChanged, ValueChanged<double> ? onChangeStart, ValueChanged<double> ? onChangeEnd, double min = 0, double max = 100, double step = 1, Color? activeColor, Color? inactiveColor, double? barHeight, double? buttonSize, Widget? button, bool disabled = false, bool readOnly = false, bool reverse = false, bool vertical = false, double? height, Duration tapAnimationDuration = const Duration(milliseconds: 200)}) -
const
-
BetterSlider.range({Key? key, required RangeValues? values, required ValueChanged<
RangeValues> onChanged, ValueChanged<RangeValues> ? onRangeChangeStart, ValueChanged<RangeValues> ? onRangeChangeEnd, double min = 0, double max = 100, double step = 1, Color? activeColor, Color? inactiveColor, double? barHeight, double? buttonSize, Widget? startButton, Widget? endButton, bool disabled = false, bool readOnly = false, bool reverse = false, bool vertical = false, double? height, Duration tapAnimationDuration = const Duration(milliseconds: 200)}) -
const
Properties
- activeColor → Color?
-
final
- barHeight → double?
-
final
-
final
-
final
- controller → BetterSliderController?
-
final
- disabled → bool
-
final
- endButton → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Required space along the main axis when vertical is true.
final
- inactiveColor → Color?
-
final
- isRange → bool
-
no setter
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- max → double
-
final
- min → double
-
final
-
onChanged
→ ValueChanged<
double> ? -
final
-
onChangeEnd
→ ValueChanged<
double> ? -
final
-
onChangeStart
→ ValueChanged<
double> ? -
final
-
onRangeChanged
→ ValueChanged<
RangeValues> ? -
final
-
onRangeChangeEnd
→ ValueChanged<
RangeValues> ? -
final
-
onRangeChangeStart
→ ValueChanged<
RangeValues> ? -
final
- readOnly → bool
-
final
- reverse → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startButton → Widget?
-
final
- step → double
-
final
- tapAnimationDuration → Duration
-
final
- value → double?
-
final
- values → RangeValues?
-
final
- vertical → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BetterSlider> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited