BetterTimePicker class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
show(BuildContext context, {String? title, List<int>? defaultValue, String? cancelText, String? confirmText, Widget? titleWidget, Color? backgroundColor, Color? cancelTextColor, Color? confirmTextColor, BorderRadiusGeometry? borderRadius, bool isDefaultShowNow = true, List<int>? minDate, List<int>? maxDate, List<BetterTimePickerColumnType>? columnTypes = const [BetterTimePickerColumnType.hour, BetterTimePickerColumnType.minute, BetterTimePickerColumnType.second], dynamic formatter(BetterTimePickerFormatterOption)?, dynamic filter(BetterTimePickerFilterOption)?, VoidCallback? onCancel, dynamic onConfirm(List<BetterPickerItem>)?, dynamic onChange(List<BetterPickerItem>)?, VoidCallback? onClose, double? diameterRatio, double? itemHeight, Widget? overlayWidget})
→ void
-