BetterToast class
一个简单的 Toast 帮助器,支持文本、成功/错误和加载变体。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
hideLoading(
) → void -
show(
BuildContext context, {String? message, Widget? child, Widget? icon, Duration? fadeDuration, Duration? duration, double? fontSize, Color? textColor, Color? backgroundColor, EdgeInsets? padding, BorderRadius? borderRadius, BetterToastPosition position = BetterToastPosition.bottom, double? topOffset, double? bottomOffset, TextAlign? textAlign = TextAlign.center, bool? forbidClick = false, double? width, double? height}) → void -
showError(
BuildContext context, {String? message, bool forbidClick = false, double? iconSize, Color? iconColor, Color? textColor, double? fontSize}) → void -
showLoading(
BuildContext context, {String? message, bool forbidClick = false, Color? barrierColor, double? progressSize, Color? progressColor = Colors.white, double? progressStrokeWidth = 2, double? borderRadius, EdgeInsetsGeometry? padding, Duration? fadeDuration, TextStyle? textStyle}) → void -
showSuccess(
BuildContext context, {String? message, bool forbidClick = false, double? iconSize, Color? iconColor, Color? textColor, double? fontSize}) → void