BetterUi class
Global Better UI configuration for responsive sizing, themes and locale.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BetterUi
Constructors
-
BetterUi({Key? key, Widget? child, BetterUiBuilder? builder, double designWidth = 375, double designHeight = 812, ThemeData? theme, ThemeData? darkTheme, ThemeData themeBuilder()?, ThemeData darkThemeBuilder()?, ThemeMode themeMode = ThemeMode.system, Map<
String, Map< translations = const {}, Locale locale = const Locale('en', 'US'), Locale fallbackLocale = const Locale('en', 'US')})String, String> > -
const
Properties
- builder → BetterUiBuilder?
-
final
- child → Widget?
-
final
- darkTheme → ThemeData?
-
final
- darkThemeBuilder → ThemeData Function()?
-
final
- designHeight → double
-
final
- designWidth → double
-
final
- fallbackLocale → Locale
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locale → Locale
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ThemeData?
-
final
- themeBuilder → ThemeData Function()?
-
final
- themeMode → ThemeMode
-
final
-
translations
→ Map<
String, Map< String, String> > -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BetterUi> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- currentContext → BuildContext?
-
no setter
- currentDarkTheme → ThemeData
-
no setter
- currentLocale → Locale
-
no setter
- currentTheme → ThemeData
-
no setter
- currentThemeMode → ThemeMode
-
no setter
-
final
- overlay → OverlayState?
-
no setter
-
supportedLocales
→ List<
Locale> -
no setter
Static Methods
-
changeDarkTheme(
ThemeData darkTheme) → void -
changeTheme(
ThemeData theme) → void -
changeThemeMode(
ThemeMode themeMode) → void -
changeThemes(
{required ThemeData theme, required ThemeData darkTheme}) → void -
localeOf(
BuildContext context) → Locale -
toggleTheme(
) → void -
translate(
String key) → String -
updateLocale(
Locale locale) → void