BetterTranslationExtension extension
Translates a string using the translations configured on BetterUi.
- on
Properties
- tr → String
-
Available on String, provided by the BetterTranslationExtension extension
no setter
Translates a string using the translations configured on BetterUi.
Available on String, provided by the BetterTranslationExtension extension