onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
// 初始化时获取系统主题
_updateThemeFromSystem();
}
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
@override
void onInit() {
super.onInit();
// 初始化时获取系统主题
_updateThemeFromSystem();
}