BetterDialogTheme class
Constructors
Properties
- bgColor → Color?
-
final
- cancelButtonColor → Color?
-
final
- confirmButtonColor → Color?
-
final
- contentColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleColor → Color?
-
final
Methods
-
copyWith(
{Color? bgColor, Color? titleColor, Color? contentColor, Color? cancelButtonColor, Color? confirmButtonColor}) → BetterDialogTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
BetterDialogTheme cellTheme, BetterDialogTheme otherCellTheme, double t) → BetterDialogTheme