BetterPickerTheme class
Constructors
- BetterPickerTheme({Color? headerBackgroundColor, Color? backgroundColor, BorderRadiusGeometry? borderRadius, String? cancelText, String? confirmText, Color? cancelTextColor, double? itemHeight, Color? overlayStartColor, Color? overlayEndColor})
Properties
- backgroundColor → Color?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- cancelText → String?
-
final
- cancelTextColor → Color?
-
final
- confirmText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBackgroundColor → Color?
-
final
- itemHeight → double?
-
final
- overlayEndColor → Color?
-
final
- overlayStartColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Color? headerBackgroundColor, Color? backgroundColor, BorderRadiusGeometry? borderRadius, String? cancelText, String? confirmText, Color? cancelTextColor, double? itemHeight, Color? overlayStartColor, Color? overlayEndColor}) → BetterPickerTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
BetterPickerTheme pickerTheme, BetterPickerTheme otherPickerTheme, double t) → BetterPickerTheme