BetterSwitchTheme class
Constructors
- BetterSwitchTheme({double? width, double? height, Color? ballBackgroundColor, Color? inactiveBackgroundColor, Color? activeBackgroundColor, EdgeInsetsGeometry? padding, double? loadingSize, double? loadingStrokeWidth, Color? loadingColor})
Properties
- activeBackgroundColor → Color?
-
final
- ballBackgroundColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- inactiveBackgroundColor → Color?
-
final
- loadingColor → Color?
-
final
- loadingSize → double?
-
final
- loadingStrokeWidth → double?
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
final
Methods
-
copyWith(
{double? width, double? height, Color? ballBackgroundColor, double? ballWidth, double? ballHeight, Color? inactiveBackgroundColor, Color? activeBackgroundColor, EdgeInsetsGeometry? padding, double? loadingSize, double? loadingStrokeWidth, Color? loadingColor}) → BetterSwitchTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited