BetterUtil class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
debounce(
Function func, [Duration delay = const Duration(milliseconds: 500)]) → Function -
防抖函数封装
func: 要执行的函数delay: 防抖时间(毫秒) -
getThemeExtension(
BuildContext context) → BetterThemeExtension? -
init(
BuildContext context, {double designWidth = 375, double designHeight = 812, bool? minTextAdapt, bool? enableScaleWH}) → void -
shouldUseHairlineBorder(
BuildContext context) → bool -
throttle(
Function func, [Duration delay = const Duration(milliseconds: 200)]) → Function -
节流函数封装
func: 要执行的函数delay: 节流时间(毫秒)